## 0.1.4 (2024-01-26)

- Fixed bug with `inner_loops` and `outer_loops`

## 0.1.3 (2023-06-20)

- Fixed bug when jump > 1

## 0.1.2 (2022-10-08)

- Fixed warnings

## 0.1.1 (2021-10-25)

- Added `seasonal_strength` and `trend_strength` functions
- Switched from assertions to exceptions

## 0.1.0 (2021-10-15)

- First release
